@@ -7,7 +7,7 @@ class AtfFileType(BaseModel):
     """
 
     id = models.AutoField(db_column="FileTypeID", primary_key=True)
-    uuid = models.CharField(db_column="Guid", max_length=36, unique=True, default=uuid.uuid4)
+    uuid = models.CharField(db_column="Guid", max_length=36, unique=True, default=uuid4)
 
     code = models.CharField(db_column="Code", max_length=100, default="")
     name = models.TextField(db_column="Name")
