@@ -13,7 +13,7 @@ class HltPolisMkab(BaseModel):
     is_active = models.BooleanField(db_column="isActive")
     s_pol = models.CharField(db_column="S_POL", max_length=50)
     n_pol = models.CharField(db_column="N_POL", max_length=50)
-    profit_type = models.IntegerField("OmsKlProfitType", db_column="rf_kl_ProfitTypeID", **FK_DEFAULT)
+    profit_type = models.ForeignKey("OmsKlProfitType", db_column="rf_kl_ProfitTypeID", **FK_DEFAULT)
     tip_oms = models.ForeignKey("OmsKlTipOms", db_column="rf_kl_TipOMSID", **FK_DEFAULT)
     mkab = models.ForeignKey("HltMkab", db_column="rf_MKABID", **FK_DEFAULT)
     smo = models.ForeignKey("OmsLpu", db_column="rf_SMOID", **FK_DEFAULT)
