@@ -16,7 +16,7 @@ class HltTap(BaseModel):
     care_person_sex = models.BooleanField(db_column="CarePersonSex", default=0)
     care_person_age = models.IntegerField(db_column="CarePersonAge", default=0)
     date_tap = models.DateTimeField(db_column="DateTAP", default=timezone.now)
-    inv = models.IntegerField(db_column="rf_INVID", default=0)
+    inv_id = models.IntegerField(db_column="rf_INVID", default=0)
     not_work_doc_status = models.IntegerField(db_column="rf_NotWorkDocStatusID", default=0)
     date_close = models.DateTimeField(db_column="DateClose", default=timezone.now)
     lpu_doctor = models.ForeignKey("HltLpuDoctor", db_column="rf_LPUDoctorID", **FK_DEFAULT)
